@@ -642,9 +642,15 @@ SERVICE_VERSIONS = {
     "wav": [
         "2021-01-29"
     ],
+    "wedata": [
+        "2021-08-20"
+    ],
     "wss": [
         "2018-04-26"
     ],
+    "yinsuda": [
+        "2022-05-27"
+    ],
     "youmall": [
         "2018-02-28"
     ],
